Enum diem_data_client::ResponseError [−][src]
pub enum ResponseError {
InvalidData,
InvalidPayloadDataType,
ProofVerificationError,
}Expand description
A response error that users of the Diem Data Client can use to notify the Data Client about invalid or malformed responses.
Variants