Struct diem_data_client::AdvertisedData [−][src]
pub struct AdvertisedData {
pub account_states: Vec<CompleteDataRange<Version>>,
pub epoch_ending_ledger_infos: Vec<CompleteDataRange<Epoch>>,
pub synced_ledger_infos: Vec<LedgerInfoWithSignatures>,
pub transactions: Vec<CompleteDataRange<Version>>,
pub transaction_outputs: Vec<CompleteDataRange<Version>>,
}Expand description
A summary of all data that is currently advertised in the network.
Fields
account_states: Vec<CompleteDataRange<Version>>The ranges of account states advertised, e.g., if a range is (X,Y), it means all account states are held for every version X->Y (inclusive).
epoch_ending_ledger_infos: Vec<CompleteDataRange<Epoch>>The ranges of epoch ending ledger infos advertised, e.g., if a range is (X,Y), it means all epoch ending ledger infos for epochs X->Y (inclusive) are available.
synced_ledger_infos: Vec<LedgerInfoWithSignatures>The ledger infos corresponding to the highest synced versions currently advertised.
transactions: Vec<CompleteDataRange<Version>>The ranges of transactions advertised, e.g., if a range is (X,Y), it means all transactions for versions X->Y (inclusive) are available.
transaction_outputs: Vec<CompleteDataRange<Version>>The ranges of transaction outputs advertised, e.g., if a range is (X,Y), it means all transaction outputs for versions X->Y (inclusive) are available.
Implementations
pub fn contains_range(
lowest: u64,
highest: u64,
advertised_ranges: &[CompleteDataRange<u64>]
) -> bool
pub fn contains_range(
lowest: u64,
highest: u64,
advertised_ranges: &[CompleteDataRange<u64>]
) -> bool
Returns true iff all data items (lowest to highest, inclusive) can
be found in the given advertised_ranges.
Returns the highest epoch ending ledger info advertised in the network
Returns the highest synced ledger info advertised in the network